<?php
namespace bwdtmc_teamcarousel_namespace;

use bwdtmc_teamcarousel_namespace\PageSettings\Page_Settings;
define( "BWDTMC_TEST_ASFSK_ASSETS_PUBLIC_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/public" );
define( "BWDTMC_TEST_ASFSK_ASSETS_ADMIN_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/admin" );
class BWDTCMMeetTeamcarousel {

	private static $_instance = null;

	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function bwdtmc_admin_editor_scripts() {
		add_filter( 'script_loader_tag', [ $this, 'bwdtmc_admin_editor_scripts_as_a_module' ], 10, 2 );
	}

	public function bwdtmc_admin_editor_scripts_as_a_module( $tag, $handle ) {
		if ( 'bwdtmc_meet_the_team_editor' === $handle ) {
			$tag = str_replace( '<script', '<script type="module"', $tag );
		}

		return $tag;
	}

	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/bwdtmc-teamcarousel-widget.php' );
	}

	public function bwdtmc_register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		// Register WidgetsF
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\BWDTMCTeamcarousel() );
	}

	private function add_page_settings_controls() {
		require_once( __DIR__ . '/page-settings/manager.php' );
		new Page_Settings();
	}

	// Register Category
	function bwdtmc_teamcarousel_add_elementor_widget_categories( $elements_manager ) {

		$elements_manager->add_category(
			'bwdtmc-team-carousel-category',
			[
				'title' => esc_html__( 'Team Member Carousel', 'bwdtmc-team-carousel' ),
				'icon' => 'eicon-person',
			]
		);
	}
	public function bwdtmc_all_assets_for_the_public(){

		wp_enqueue_script( 'the-snake', plugin_dir_url( __FILE__ ) . 'assets/public/js/snake.js', array('jquery'), '1.3', true );

		wp_enqueue_script( 'interactive-owlcarousel', plugin_dir_url( __FILE__ ) . 'assets/public/js/owl.carousel.min.js', array('jquery'), '1.3', true );

		wp_enqueue_script( 'the-min', plugin_dir_url( __FILE__ ) . 'assets/public/js/min.js', array('jquery'), '1.3', true );

		$all_css_js_file = array(
			
            'team-plugin-fontawesome' => array('bwdtmc_path_define'=>BWDTMC_TEST_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/all.min.css'),

            'team-plugin-owlcarousel-style' => array('bwdtmc_path_define'=>BWDTMC_TEST_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/owl.carousel.min.css'),

            'team-plugin-owltheme-style' => array('bwdtmc_path_define'=>BWDTMC_TEST_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/owl.theme.default.min.css'),

			'team-main-style' => array('bwdtmc_path_define'=>BWDTMC_TEST_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/bwdtmc-team-main.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdtmc_path_define'], null, '1.3', 'all');
        }
	}
	public function bwdtmc_all_assets_for_elementor_editor_admin(){
		$all_css_js_file = array(
            'team-admin-main' => array('bwdtmc_path_admin_define'=>BWDTMC_TEST_ASFSK_ASSETS_ADMIN_DIR_FILE . '/icon.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdtmc_path_admin_define'], null, '1.3', 'all');
        }
	}

	public function __construct() {
		// For public assets
		add_action('wp_enqueue_scripts', [$this, 'bwdtmc_all_assets_for_the_public']);

		// For Elementor Editor
		add_action('elementor/editor/before_enqueue_scripts', [$this, 'bwdtmc_all_assets_for_elementor_editor_admin']);
		
		// Register Category
		add_action( 'elementor/elements/categories_registered', [ $this, 'bwdtmc_teamcarousel_add_elementor_widget_categories' ] );

		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'bwdtmc_register_widgets' ] );

		// Register editor scripts
		add_action( 'elementor/editor/after_enqueue_scripts', [ $this, 'bwdtmc_admin_editor_scripts' ] );
		
		$this->add_page_settings_controls();
	}
}

// Instantiate Plugin Class
BWDTCMMeetTeamcarousel::instance();